@@ -1,9 +1,9 @@
 package Acme::MadokaMagica::TvMembers::KanameMadoka;
-use Mouse;
-extends 'Acme::MadokaMagica::TvMembers';
+use parent 'Acme::MadokaMagica::TvMembers';
+use strict;
+use warnings;
 use utf8;
 
-no Mouse;
 
 1;
 
